/* and the real names of the random devices */
#undef NAME_OF_DEV_RANDOM
#undef NAME_OF_DEV_URANDOM
#undef HAVE_DEV_RANDOM

#undef USE_MHASH

#undef PACKAGE
#undef VERSION

#undef T_CPU
#undef T_VENDOR
#undef T_OS

#undef LT_CURRENT
#undef LT_REVISION
#undef LT_AGE
#undef USE_DMALLOC
#undef USE_EFENCE
#undef USE_LIBCALLOC

#undef USE_GCRYPT
#undef GNUTLS_VERSION

#undef USE_SIGNALS
#undef USE_VA_COPY
#undef HAVE_VA_COPY
#undef HAVE___VA_COPY

#undef LIBMCRYPT22
#undef LIBMCRYPT24

#undef NO_SIZE_T
#undef NO_TIME_T

#undef DEFINE_SIZE_T

#undef ENABLE_SRP
#undef ENABLE_ANON
